@@ -120,7 +120,7 @@ public:
     /** Returns the history store used by this emulation.  See setHistory() */
     const HistoryType &history() const;
     /** Clears the history scroll. */
-    void clearHistory();
+    virtual void clearHistory();
 
     /**
      * Copies the output history from @p startLine to @p endLine
@@ -177,8 +177,9 @@ public:
 
     /** Resets the state of the terminal.
      *
-     * @param softReset The reset was initiated by DECSTR */
-    virtual void reset(bool softReset = false) = 0;
+     * @param softReset The reset was initiated by DECSTR
+     * @param preservePrompt Try to preserve the command prompt */
+    virtual void reset(bool softReset = false, bool preservePrompt = false) = 0;
 
     /**
      * Returns true if the active terminal program is interested in Mouse
@@ -402,6 +403,8 @@ Q_SIGNALS:
      */
     void resetCursorStyleRequest();
 
+    void toggleUrlExtractionRequest();
+
 protected:
     virtual void setMode(int mode) = 0;
     virtual void resetMode(int mode) = 0;
@@ -430,7 +433,7 @@ protected:
 
     QList<ScreenWindow *> _windows;
 
-    Screen *_currentScreen; // pointer to the screen which is currently active,
+    Screen *_currentScreen = nullptr; // pointer to the screen which is currently active,
     // this is one of the elements in the screen[] array
 
     Screen *_screen[2]; // 0 = primary screen ( used by most programs, including the shell
@@ -440,9 +443,9 @@ protected:
 
     // decodes an incoming C-style character stream into a unicode QString using
     // the current text codec.  (this allows for rendering of non-ASCII characters in text files etc.)
-    const QTextCodec *_codec;
+    const QTextCodec *_codec = nullptr;
     std::unique_ptr<QTextDecoder> _decoder;
-    const KeyboardTranslator *_keyTranslator; // the keyboard layout
+    const KeyboardTranslator *_keyTranslator = nullptr; // the keyboard layout
 
 protected Q_SLOTS:
     /**
@@ -471,13 +474,13 @@ private:
     void setScreenInternal(int index);
     Q_DISABLE_COPY(Emulation)
 
-    bool _usesMouseTracking;
-    bool _bracketedPasteMode;
-    QTimer _bulkTimer1;
-    QTimer _bulkTimer2;
-    bool _imageSizeInitialized;
-    bool _peekingPrimary;
-    int _activeScreenIndex;
+    bool _usesMouseTracking = false;
+    bool _bracketedPasteMode = false;
+    QTimer _bulkTimer1{this};
+    QTimer _bulkTimer2{this};
+    bool _imageSizeInitialized = false;
+    bool _peekingPrimary = false;
+    int _activeScreenIndex = 0;
 };
 }
 
