@@ -91,6 +91,7 @@ MainWindow::MainWindow()
     connect(_viewManager, &Konsole::ViewManager::newViewWithProfileRequest, this, &Konsole::MainWindow::newFromProfile);
     connect(_viewManager, &Konsole::ViewManager::newViewRequest, this, &Konsole::MainWindow::newTab);
     connect(_viewManager, &Konsole::ViewManager::terminalsDetached, this, &Konsole::MainWindow::terminalsDetached);
+    connect(_viewManager, &Konsole::ViewManager::activationRequest, this, &Konsole::MainWindow::activationRequest);
 
     setCentralWidget(_viewManager->widget());
 
@@ -153,6 +154,12 @@ void MainWindow::updateUseTransparency()
     WindowSystemInfo::HAVE_TRANSPARENCY = useTranslucency;
 }
 
+void MainWindow::activationRequest(const QString &xdgActivationToken)
+{
+    KWindowSystem::setCurrentXdgActivationToken(xdgActivationToken);
+    KWindowSystem::forceActiveWindow(winId());
+}
+
 void MainWindow::rememberMenuAccelerators()
 {
     const QList<QAction *> actions = menuBar()->actions();
@@ -257,6 +264,10 @@ void MainWindow::activeViewChanged(SessionController *controller)
 
     // Update window icon to newly activated session's icon
     updateWindowIcon();
+
+    for (IKonsolePlugin *plugin : _plugins) {
+        plugin->activeViewChanged(controller, this);
+    }
 }
 
 void MainWindow::activeViewTitleChanged(ViewProperties *properties)
@@ -301,7 +312,7 @@ void MainWindow::setupActions()
 
     // File Menu
     _newTabMenuAction = new KActionMenu(QIcon::fromTheme(QStringLiteral("tab-new")), i18nc("@action:inmenu", "&New Tab"), collection);
-    collection->setDefaultShortcut(_newTabMenuAction, Konsole::ACCEL | Qt::SHIFT | Qt::Key_T);
+    collection->setDefaultShortcut(_newTabMenuAction, Konsole::ACCEL | Qt::Key_T);
     collection->setShortcutsConfigurable(_newTabMenuAction, true);
     _newTabMenuAction->setAutoRepeat(false);
     connect(_newTabMenuAction, &KActionMenu::triggered, this, &MainWindow::newTab);
@@ -318,14 +329,14 @@ void MainWindow::setupActions()
     menuAction = collection->addAction(QStringLiteral("new-window"));
     menuAction->setIcon(QIcon::fromTheme(QStringLiteral("window-new")));
     menuAction->setText(i18nc("@action:inmenu", "New &Window"));
-    collection->setDefaultShortcut(menuAction, Konsole::ACCEL | Qt::SHIFT | Qt::Key_N);
+    collection->setDefaultShortcut(menuAction, Konsole::ACCEL | Qt::Key_N);
     menuAction->setAutoRepeat(false);
     connect(menuAction, &QAction::triggered, this, &Konsole::MainWindow::newWindow);
 
     menuAction = collection->addAction(QStringLiteral("close-window"));
     menuAction->setIcon(QIcon::fromTheme(QStringLiteral("window-close")));
     menuAction->setText(i18nc("@action:inmenu", "Close Window"));
-    collection->setDefaultShortcut(menuAction, Konsole::ACCEL | Qt::SHIFT | Qt::Key_Q);
+    collection->setDefaultShortcut(menuAction, Konsole::ACCEL | Qt::Key_Q);
     connect(menuAction, &QAction::triggered, this, &Konsole::MainWindow::close);
 
     // Bookmark Menu
@@ -337,7 +348,7 @@ void MainWindow::setupActions()
 
     // Settings Menu
     _toggleMenuBarAction = KStandardAction::showMenubar(menuBar(), &QMenuBar::setVisible, collection);
-    collection->setDefaultShortcut(_toggleMenuBarAction, Konsole::ACCEL | Qt::SHIFT | Qt::Key_M);
+    collection->setDefaultShortcut(_toggleMenuBarAction, Konsole::ACCEL | Qt::Key_M);
     // Set up themes
     actionCollection()->addAction(QStringLiteral("window-colorscheme-menu"), new AppColorSchemeChooser(actionCollection()));
 
@@ -357,7 +368,7 @@ void MainWindow::setupActions()
     // Set up an shortcut-only action for activating menu bar.
     menuAction = collection->addAction(QStringLiteral("activate-menu"));
     menuAction->setText(i18nc("@item", "Activate Menu"));
-    collection->setDefaultShortcut(menuAction, Konsole::ACCEL | Qt::SHIFT | Qt::Key_F10);
+    collection->setDefaultShortcut(menuAction, Konsole::ACCEL | Qt::Key_F10);
     connect(menuAction, &QAction::triggered, this, &Konsole::MainWindow::activateMenuBar);
 
     auto action = collection->addAction(QStringLiteral("save-layout"));
@@ -471,8 +482,8 @@ void MainWindow::newTab()
 
 void MainWindow::addPlugin(IKonsolePlugin *plugin)
 {
-    _plugins.append(plugin);
-    connect(_viewManager, &Konsole::ViewManager::activeViewChanged, plugin, &IKonsolePlugin::activeViewChanged);
+    Q_ASSERT(std::find(_plugins.cbegin(), _plugins.cend(), plugin) == _plugins.cend());
+    _plugins.push_back(plugin);
 }
 
 void MainWindow::cloneTab()
@@ -769,13 +780,13 @@ void MainWindow::showSettingsDialog(const bool showProfilePage)
 
     auto *profileSettings = new ProfileSettings(confDialog);
     auto *profilePage = new KPageWidgetItem(profileSettings, profilePageName);
-    profilePage->setIcon(QIcon::fromTheme(QStringLiteral("preferences-system-profiles")));
+    profilePage->setIcon(QIcon::fromTheme(QStringLiteral("preferences-desktop-theme")));
     confDialog->addPage(profilePage, true);
     connect(confDialog, &QDialog::accepted, profileSettings, &ProfileSettings::slotAccepted);
 
     const QString tabBarPageName = i18nc("@title Preferences page name", "Tab Bar / Splitters");
     auto tabBarPage = new KPageWidgetItem(new TabBarSettings(confDialog), tabBarPageName);
-    tabBarPage->setIcon(QIcon::fromTheme(QStringLiteral("system-run")));
+    tabBarPage->setIcon(QIcon::fromTheme(QStringLiteral("preferences-tabs")));
     confDialog->addPage(tabBarPage, true);
 
     const QString temporaryFilesPageName = i18nc("@title Preferences page name", "Temporary Files");
@@ -904,7 +915,7 @@ void MainWindow::showEvent(QShowEvent *event)
             // Delay resizing to here, so that the other parts of the UI
             // (ViewManager, TabbedViewContainer, TerminalDisplay ... etc)
             // have been created and TabbedViewContainer::sizeHint() returns
-            // a usuable size.
+            // a usable size.
 
             // Remove the WindowMaximized state to override the Window-Maximized
             // config key
